PFASUM: PFASUM Amino Acid Substitution Matrices

Description Usage Format Details Source Examples

Description

The PFASUM amino acid substitution matrices defined by Keul, F., et al. (2017).

Usage

1
data("PFASUM")

Format

The format is: num [1:25, 1:25, 1:90] 0.9492 -1.7337 0.2764 1.8153 0.0364 ... - attr(*, "dimnames")=List of 3 ..$ : chr [1:25] "A" "R" "N" "D" ... ..$ : chr [1:25] "A" "R" "N" "D" ... ..$ : chr [1:90] "11" "12" "13" "14" ...

Details

Substitution matrix values represent the log-odds of observing an aligned pair of amino acids versus the likelihood of finding the pair by chance. The PFASUM substitution matrices are stored as an array named by each sub-matrix's similarity threshold. (See examples section below.) In all cases values are in units of third-bits (log(odds\ ratio)*3/log(2)).

Keul, F., et al. (2017). PFASUM: a substitution matrix from Pfam structural alignments. BMC Bioinformatics, 18(1), 293.

Examples

1
2
3
4
5
6
7
data(PFASUM)
PFASUM31 <- PFASUM[,, "31"] # the PFASUM31 matrix
PFASUM31["A", "R"] # score for A/R pairing

data(BLOSUM62)
plot(BLOSUM62[1:20, 1:20], PFASUM31[1:20, 1:20])
abline(a=0, b=1)

Example output

Loading required package: Biostrings
Loading required package: BiocGenerics
Loading required package: parallel

Attaching package: ‘BiocGenerics’

The following objects are masked from ‘package:parallel’:

    clusterApply, clusterApplyLB, clusterCall, clusterEvalQ,
    clusterExport, clusterMap, parApply, parCapply, parLapply,
    parLapplyLB, parRapply, parSapply, parSapplyLB

The following objects are masked from ‘package:stats’:

    IQR, mad, sd, var, xtabs

The following objects are masked from ‘package:base’:

    anyDuplicated, append, as.data.frame, basename, cbind, colnames,
    dirname, do.call, duplicated, eval, evalq, Filter, Find, get, grep,
    grepl, intersect, is.unsorted, lapply, Map, mapply, match, mget,
    order, paste, pmax, pmax.int, pmin, pmin.int, Position, rank,
    rbind, Reduce, rownames, sapply, setdiff, sort, table, tapply,
    union, unique, unsplit, which.max, which.min

Loading required package: S4Vectors
Loading required package: stats4

Attaching package: ‘S4Vectors’

The following object is masked from ‘package:base’:

    expand.grid

Loading required package: IRanges
Loading required package: XVector

Attaching package: ‘Biostrings’

The following object is masked from ‘package:base’:

    strsplit

Loading required package: RSQLite
[1] -0.768

DECIPHER documentation built on Nov. 8, 2020, 8:30 p.m.